@@ -1,6 +1,5 @@
 from hellosign.utils.request import HSRequest
-from hellosign.utils.exception import HSException, InvalidEmail
-from hellosign.utils.exception import EmptyPassword, NoAuthMethod
+from hellosign.utils.exception import HSException, NoAuthMethod
 from hellosign.utils.exception import HTTPError
 from hellosign.resource.account import Account
 from hellosign.resource.signature_request import SignatureRequest
@@ -9,7 +8,6 @@ from hellosign.resource.team import Team
 from hellosign.resource.embedded import Embedded
 from hellosign.resource.unclaimed_draft import UnclaimedDraft
 from hellosign.utils.hsaccesstokenauth import HSAccessTokenAuth
-import hellosign.utils.utils as utils
 from requests.auth import HTTPBasicAuth
 
 
@@ -58,26 +56,26 @@ class HSClient(object):
 
     OAUTH_TOKEN_URL = ''
 
-    def __init__(self, api_email=None, api_password=None, api_key=None,
-                 api_accesstoken=None, api_accesstokentype=None,
+    def __init__(self, email=None, password=None, api_key=None,
+                 access_token=None, access_token_type="Bearer",
                  env='production'):
         """Initialize the client object with authentication information to send
         requests
 
         Args:
-            api_email (str): E-mail of the account to make the requests
-            api_password (str): Password of the account used with email address
+            email (str): E-mail of the account to make the requests
+            password (str): Password of the account used with email address
             api_key (str): API Key. You can find your API key in
              https://www.hellosign.com/home/myAccount/current_tab/integrations
-            api_accesstoken (str):
-            api_accesstokentype (str):
+            access_token (str):
+            access_token_type (str):
 
         """
 
         super(HSClient, self).__init__()
         self.auth = self._authenticate(
-            api_email, api_password, api_key, api_accesstoken,
-            api_accesstokentype)
+            email, password, api_key, access_token,
+            access_token_type)
         self.account = Account()
         # self.get_account_info()
         self._init_endpoints(env)
@@ -150,12 +148,6 @@ class HSClient(object):
 
         """
 
-        if not email:
-            raise InvalidEmail("Email cannot be empty")
-        elif not utils.is_email(email):
-            raise InvalidEmail("Email is not valid")
-        if not password:
-            raise EmptyPassword("Password cannot be empty")
         request = HSRequest(self.auth)
         response = request.post(self.ACCOUNT_CREATE_URL, {
                                 'email_address': email, 'password': password})
@@ -924,7 +916,6 @@ class HSClient(object):
             files=files_payload)
         return UnclaimedDraft(response["unclaimed_draft"])
 
-
     def get_oauth_data(self, code, client_id, secret, state):
         """Get Oauth data from HelloSign
 
@@ -948,19 +939,19 @@ class HSClient(object):
             response['expires_in'], response['state'])
         return oauth
 
-    def _authenticate(self, api_email=None, api_password=None, api_key=None,
-                      api_accesstoken=None, api_accesstokentype=None):
+    def _authenticate(self, email=None, password=None, api_key=None,
+                      access_token=None, access_token_type=None):
         """Create authentication object to send requests
 
         Args:
-            api_email (str): E-mail of the account to make the requests
+            email (str): E-mail of the account to make the requests
 
-            api_password (str): Password of the account used with email address
+            password (str): Password of the account used with email address
 
             api_key (str): API Key. You can find your API key in
              https://www.hellosign.com/home/myAccount/current_tab/integrations
-            api_accesstoken (str):
-            api_accesstokentype (str):
+            access_token (str):
+            access_token_type (str):
 
         Raises:
             NoAuthMethod: If no authentication information found
@@ -970,12 +961,12 @@ class HSClient(object):
 
         """
 
-        if api_accesstokentype and api_accesstoken:
-            return HSAccessTokenAuth(api_accesstokentype, api_accesstoken)
+        if access_token_type and access_token:
+            return HSAccessTokenAuth(access_token_type, access_token)
         elif api_key:
             return HTTPBasicAuth(api_key, '')
-        elif api_email and api_password:
-            return HTTPBasicAuth(api_email, api_password)
+        elif email and password:
+            return HTTPBasicAuth(email, password)
         else:
             raise NoAuthMethod("No authentication information found!")
 
@@ -1227,8 +1218,7 @@ class HSClient(object):
 
         if not email_address and not account_id:
             raise HSException("No email address or account_id specified")
-        elif email_address and not utils.is_email(email_address):
-            raise InvalidEmail("Email is not valid")
+
         request = HSRequest(self.auth)
         data = {}
         if account_id is not None:
@@ -1257,8 +1247,7 @@ class HSClient(object):
 
         if not email_address and not account_id:
             raise HSException("No email address or account_id specified")
-        elif email_address and not utils.is_email(email_address):
-            raise InvalidEmail("Email is not valid")
+
         request = HSRequest(self.auth)
         data = {}
         if account_id is not None:
